=======
History
=======

0.1.6 (2021-06-10)
------------------

- fixed bugs
- better config example
- can send multiple keystrokes with one 'press:' directive
- after rule is enabled/disabled - rebind keys.

0.1.5 (2021-06-10)
------------------

- fixed bugs

0.1.4 (2021-06-10)
------------------

- changed config format
- added timer events
- added negative conditions like ne for not-equal
- added and/or logic in config

0.1.2 (2021-06-09)
------------------

* "then" block can now be list

0.1.1 (2021-06-09)
------------------

* Fixed bugs

0.1.0 (2021-05-14)
------------------

* First release on PyPI.
